Blackfin arch: fix bug - sometimes there is no response to the hitting key in uboot for bf561-ezkit when running with 50mhz SCLK

Previous message: [thread] [date] [author]
Next message: [thread] [date] [author]

Gitweb:     http://git.kernel.org/git/?p=linux/kernel/git/torvalds/linux-2.6.git;a=commit;h=fffe53...
Commit:     fffe53bee7d90ab2103d2520ab4d095aea9b7397
Parent:     5c64e0d5109532f8184be29c1dc163059e3ded4b
Author:     Mike Frysinger <vapier.adi@gmail.com>
AuthorDate: Wed Oct 8 14:46:09 2008 +0800
Committer:  Bryan Wu <cooloney@kernel.org>
CommitDate: Wed Oct 8 14:46:09 2008 +0800

    Blackfin arch: fix bug - sometimes there is no response to the hitting key in uboot for bf561-ezkit when running with 50mhz SCLK
    
    use 10 delays rather than 7
    
    Signed-off-by: Mike Frysinger <vapier.adi@gmail.com>
    Signed-off-by: Bryan Wu <cooloney@kernel.org>
---
 arch/blackfin/kernel/reboot.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/arch/blackfin/kernel/reboot.c b/arch/blackfin/kernel/reboot.c
index 367e2dc..b0a8f89 100644
--- a/arch/blackfin/kernel/reboot.c
+++ b/arch/blackfin/kernel/reboot.c
@@ -34,15 +34,15 @@ void bfin_reset(void)
 		bfin_write_SWRST(0x7);
 
 		/* Due to the way reset is handled in the hardware, we need
 		 * to delay for 7 SCLKS.  The only reliable way to do this is
 		 * to calculate the CCLK/SCLK ratio and multiply 7.  For now,
 		 * we'll assume worse case which is a 1:15 ratio.
 		 */
 		asm(
 			"LSETUP (1f, 1f) LC0 = %0\n"
 			"1: nop;"
 			:
-			: "a" (15 * 7)
+			: "a" (15 * 10)
 			: "LC0", "LB0", "LT0"
 		);
 
@@ -34,15 +34,15 @@ void bfin_reset(void)
 
 		/* Due to the way reset is handled in the hardware, we need
-		 * to delay for 7 SCLKS.  The only reliable way to do this is
-		 * to calculate the CCLK/SCLK ratio and multiply 7.  For now,
+		 * to delay for 10 SCLKS.  The only reliable way to do this is
+		 * to calculate the CCLK/SCLK ratio and multiply 10.  For now,
 		 * we'll assume worse case which is a 1:15 ratio.
 		 */
--
To unsubscribe from this list: send the line "unsubscribe git-commits-head" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Previous message: [thread] [date] [author]
Next message: [thread] [date] [author]

Messages in current thread:
Blackfin arch: fix bug - sometimes there is no response to ..., Linux Kernel Mailing ..., (Mon Oct 13, 11:19 am)